Twitter to Discord Webhook
======
[![GitHub](https://img.shields.io/github/license/mashape/apistatus.svg)](https://raw.githubusercontent.com/poipoii/twitter2discord/master/LICENSE)
[![Build Status](https://travis-ci.org/poipoii/twitter2discord.svg?branch=master)](https://travis-ci.org/poipoii/twitter2discord)
[![Latest PyPI version](https://img.shields.io/pypi/v/twitter2discord.svg)](https://pypi.python.org/pypi/twitter2discord/)



Installation
------------

### From PyPI with `pip`

```sh
$ pip3 install twitter2discord
```